@@ -21,7 +21,7 @@ use warnings;
 no warnings qw(recursion);
 
 use vars qw($VERSION $STRING_VERSION);
-$VERSION        = '2.069_001';
+$VERSION        = '2.069_002';
 $STRING_VERSION = $VERSION;
 ## no critic(BuiltinFunctions::ProhibitStringyEval)
 $VERSION = eval $VERSION;
@@ -574,22 +574,26 @@ sub Marpa::R2::Scanless::ASF::new {
         {with the Marpa::R2::Scanless::ASF::new method}
     ) if not defined $force and not defined $default_blessing;
 
+    my $recce     = $slr->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
+
+    if ( defined $recce->[Marpa::R2::Internal::Recognizer::TREE_MODE] ) {
+        # If we already in ASF mode, or are in valuation mode, we cannot create an ASF
+        Marpa::R2::exception(
+            "An attempt was made to create an ASF for a SLIF recognizer already in use\n",
+            "   The recognizer must be reset first\n",
+            '  The current SLIF recognizer mode is "',
+            $recce->[Marpa::R2::Internal::Recognizer::TREE_MODE],
+            qq{"\n}
+        );
+    }
+    $recce->[Marpa::R2::Internal::Recognizer::TREE_MODE] = 'forest';
+
     my $slg       = $slr->[Marpa::R2::Inner::Scanless::R::GRAMMAR];
     my $thin_slr  = $slr->[Marpa::R2::Inner::Scanless::R::C];
-    my $recce     = $slr->[Marpa::R2::Inner::Scanless::R::THICK_G1_RECCE];
     my $grammar   = $recce->[Marpa::R2::Internal::Recognizer::GRAMMAR];
     my $grammar_c = $grammar->[Marpa::R2::Internal::Grammar::C];
     my $recce_c   = $recce->[Marpa::R2::Internal::Recognizer::C];
 
-    if ( $recce->[Marpa::R2::Internal::Recognizer::T_C] ) {
-
-        # If there is a tree we are in valuation mode, and cannot create an ASF
-        Marpa::R2::exception(
-            'An attempt was made to create an ASF for a SLIF recognizer in value mode',
-            '   The recognizer must be reset first'
-        );
-    } ## end if ( $recce->[Marpa::R2::Internal::Recognizer::T_C] )
-
     my $bocage = $recce->[Marpa::R2::Internal::Recognizer::B_C];
     if ( not $bocage ) {
         my $grammar   = $recce->[Marpa::R2::Internal::Recognizer::GRAMMAR];
